@@ -4,6 +4,12 @@ spam( ham[1], {eggs: 2})
 spam(ham[ 1], {eggs: 2})
 #: E201:1:15
 spam(ham[1], { eggs: 2})
+#: E201:1:6
+spam(	ham[1], {eggs: 2})
+#: E201:1:10
+spam(ham[	1], {eggs: 2})
+#: E201:1:15
+spam(ham[1], {	eggs: 2})
 #: Okay
 spam(ham[1], {eggs: 2})
 #:
@@ -15,6 +21,12 @@ spam(ham[1], {eggs: 2} )
 spam(ham[1], {eggs: 2 })
 #: E202:1:11
 spam(ham[1 ], {eggs: 2})
+#: E202:1:23
+spam(ham[1], {eggs: 2}	)
+#: E202:1:22
+spam(ham[1], {eggs: 2	})
+#: E202:1:11
+spam(ham[1	], {eggs: 2})
 #: Okay
 spam(ham[1], {eggs: 2})
 
@@ -39,13 +51,24 @@ result = [
 if x == 4 :
     print x, y
     x, y = y, x
+#: E203:1:10
+if x == 4	:
+    print x, y
+    x, y = y, x
 #: E203:2:15 E702:2:16
 if x == 4:
     print x, y ; x, y = y, x
+#: E203:2:15 E702:2:16
+if x == 4:
+    print x, y	; x, y = y, x
 #: E203:3:13
 if x == 4:
     print x, y
     x, y = y , x
+#: E203:3:13
+if x == 4:
+    print x, y
+    x, y = y	, x
 #: Okay
 if x == 4:
     print x, y
