@@ -13,6 +13,9 @@ def f3(
         b,
 ):
     pass
+
+
+lambda a, /: None
 #: Okay
 if x := 1:
     print(x)
@@ -25,3 +28,17 @@ if x:= 1:
 #: E225:1:18
 if False or (x :=1):
     pass
+#: Okay
+import typing as t
+
+__all__: t.List[str] = []
+
+import logging
+
+logging.getLogger(__name__)
+#: E402
+import typing as t
+
+all_the_things: t.List[str] = []
+
+import logging
