@@ -8,8 +8,6 @@ from pycodestyle import normalize_paths
 
 class UtilTestCase(unittest.TestCase):
     def test_normalize_paths(self):
-        cwd = os.getcwd()
-
         self.assertEqual(normalize_paths(''), [])
         self.assertEqual(normalize_paths([]), [])
         self.assertEqual(normalize_paths(None), [])
@@ -17,7 +15,11 @@ class UtilTestCase(unittest.TestCase):
         self.assertEqual(normalize_paths('foo'), ['foo'])
         self.assertEqual(normalize_paths('foo,bar'), ['foo', 'bar'])
         self.assertEqual(normalize_paths('foo,  bar  '), ['foo', 'bar'])
-        self.assertEqual(normalize_paths('/foo/bar,baz/../bat'),
-                         ['/foo/bar', cwd + '/bat'])
-        self.assertEqual(normalize_paths(".pyc,\n   build/*"),
-                         ['.pyc', cwd + '/build/*'])
+        self.assertEqual(
+            normalize_paths('/foo/bar,baz/../bat'),
+            [os.path.realpath('/foo/bar'), os.path.abspath('bat')],
+        )
+        self.assertEqual(
+            normalize_paths(".pyc,\n   build/*"),
+            ['.pyc', os.path.abspath('build/*')],
+        )
